@@ -6,6 +6,7 @@ use utf8;
 use Try::Tiny;
 use Test::More;
 use Test::Exception;
+use Test::File qw(file_exists_ok);
 use Time::HiRes qw(sleep tv_interval gettimeofday);
 use Path::Class 0.33 qw(file dir);
 use Digest::SHA qw(sha1_hex);
@@ -35,6 +36,7 @@ sub run {
         chomp  => 1,
         iomode => '<:raw'
     );
+
     # Each change should retain its own hash.
     my $orig_deploy_hash;
     $mock_change->mock(_deploy_hash => sub {
@@ -88,16 +90,15 @@ sub run {
         );
         if (my $code = $p{skip_unless}) {
             try {
-                $code->( $engine ) || die 'NO';
+                $code->( $engine ) || App::Sqitch::X::hurl('NO');
             } catch {
+                diag $_->message;
+                diag $_->previous_exception if $_->previous_exception;
                 plan skip_all => sprintf(
-                    'Unable to live-test %s engine: %s',
+                    'Unable to live-test %s engine',
                     $class->name,
-                    $_->message,
                 ) unless $ENV{'LIVE_' . uc $engine->key . '_REQUIRED'};
                 fail 'Connect to ' . $class->name;
-                diag $_->message;
-                diag $_->previous_exception;
             } or return;
         }
         if (my $q = $p{version_query}) {
@@ -1913,4 +1914,15 @@ sub get_dependencies {
     }, undef, shift);
 }
 
+sub test_templates_for {
+    my $key = $_[1];
+    # Make sure we have templates.
+    for my $action (qw(deploy revert verify)) {
+        my $fn = file(__FILE__)->dir->parent->parent->file(
+            qw(etc templates), $action, "$key.tmpl",
+        );
+        file_exists_ok($fn, "etc/templates/$action/$key.tml should exist");
+    }
+}
+
 1;
